/* ssl_rc4.h */
/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au).
 * All rights reserved.
 * Copyright remains Eric Young's, and as such any Copyright notices in
 * the code are not to be removed.
 * See the COPYRIGHT file in the SSLeay distribution for more details.
 */

typedef struct rc4_state_st
	{
	RC4_KEY rc4_read_ks;
	RC4_KEY rc4_write_ks;
	} RC4_STATE;

#ifdef PROTO
int ssl_enc_rc4_init(SSL *s, int client);
void ssl_enc_rc4(SSL *s);
#else
int ssl_enc_rc4_init();
void ssl_enc_rc4();
#endif
